@@ -54,7 +54,7 @@
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/var/adm/wtmpx"
 #define PATH_UTMP       "/var/adm/utmpx"
-#define PATH_SYSLOG     "/var/adm/message"
+#define PATH_SYSLOG     "/var/adm/messages"
 #endif
 
 #ifdef SOLARIS26
@@ -62,13 +62,13 @@
 #define HAVE_VSNPRINTF
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
-#define SOCKLEN_T       int
+#define SOCKLEN_T       size_t
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP    "/var/tmp"
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/var/adm/wtmpx"
 #define PATH_UTMP       "/var/adm/utmpx"
-#define PATH_SYSLOG     "/var/adm/message"
+#define PATH_SYSLOG     "/var/adm/messages"
 #endif
 
 #ifdef SOLARIS_OLD
@@ -80,7 +80,7 @@
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/var/adm/wtmp"
 #define PATH_UTMP       "/var/adm/utmp"
-#define PATH_SYSLOG     "/var/adm/message"
+#define PATH_SYSLOG     "/var/adm/messages"
 #endif
 
 #ifdef NEXTSTEP3
@@ -111,6 +111,7 @@
 #ifdef IRIX62
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
+#define SOCKLEN_T       int
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
 #define PATH_PASSWD     "/etc/passwd"
@@ -124,6 +125,7 @@
 #define HAVE_SNPRINTF
 #define HAVE_VSNPRINTF
 #define PID_T_IS_LONG_INT
+#define SOCKLEN_T       int
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
 #define PATH_PASSWD     "/etc/passwd"
@@ -132,7 +134,7 @@
 #define PATH_SYSLOG     "/var/adm/SYSLOG"
 #endif
 
-#ifdef AIX43
+#if defined(_AIX43) || defined (AIX43)
 #define HAVE_GETRUSAGE
 #if defined(__64BIT_KERNEL) && defined(_KERNEL)
 #define PID_T_IS_LONG_INT
