@@ -19,6 +19,7 @@
 
 static int randsavefd = -1;
 int debug = 0;
+int fg = 0;
 
 int devnull = -1;
 
@@ -171,21 +172,12 @@ static void killpeer(int service_socket)
     exit(EXIT_FAILURE);
   }
   buffer[num] = '\0';
-#ifdef PID_T_IS_LONG_INT
-  peer_id = atol((char *) buffer);
-  (void)fprintf(stderr, "Killing: %ld\n", peer_id);
-#else
-  peer_id = atoi((char *) buffer);
-  (void)fprintf(stderr, "Killing: %d\n", (int)peer_id);
-#endif
+  peer_id = (pid_t)atol((char *) buffer);
+  (void)fprintf(stderr, "Killing: %ld\n", (long)peer_id);
 
   if (kill(peer_id, SIGTERM) < 0)
   {
-#ifdef PID_T_IS_LONG_INT
-    (void)snprintf(msg_buf, sizeof(msg_buf), "Cannot kill %ld", peer_id);
-#else
-    (void)snprintf(msg_buf, sizeof(msg_buf), "Cannot kill %d", (int)peer_id);
-#endif
+    (void)snprintf(msg_buf, sizeof(msg_buf), "Cannot kill %ld", (long)peer_id);
     msg_buf[sizeof(msg_buf) - 1] = '\0';
     error_fatal(msg_buf, errno);
     exit(EXIT_FAILURE);
@@ -197,7 +189,17 @@ static void usage(const char *progname)
 {
   (void)fprintf(stderr, "prngd %s (%s)\n", PRNGD_VERSION, PRNGD_DATE);
   (void)fprintf(stderr,
-	  "Usage: %s [options] (/path/to/socket1 | tcp/localhost:port) [(/path/to/socket2 | tcp/localhost:port)] ... \nOptions:\n\t-d/--debug: debugging on\n\t-c/--cmdfile cmdpath: use cmdpath for entropy commands [%s]\n\t-s/--seedfile seedpath: use seedpath as seedfile [%s]\n\t-n/--no-seedfile: no seedfile, keep pool in memory only\n\t-m/--mode mode: use mode for sockets [%04o]\n\t-k/--kill: kill daemon on other side\n\t-v/--version: print version and exit\n",
+	  "Usage: %s [options] (/path/to/socket1 | tcp/localhost:port) "
+		"[(/path/to/socket2 | tcp/localhost:port)] ... \n"
+	  "Options:\n"
+	  "\t-f/--fg: do not fork\n"
+	  "\t-d/--debug: debugging on\n"
+	  "\t-c/--cmdfile cmdpath: use cmdpath for entropy commands [%s]\n"
+	  "\t-s/--seedfile seedpath: use seedpath as seedfile [%s]\n"
+	  "\t-n/--no-seedfile: no seedfile, keep pool in memory only\n"
+	  "\t-m/--mode mode: use mode for sockets [%04o]\n"
+	  "\t-k/--kill: kill daemon on other side\n"
+	  "\t-v/--version: print version and exit\n",
 	  progname, CONFIGFILE, RANDSAVENAME, SOCKETMODE);
 }
 
@@ -235,6 +237,8 @@ int main(int argc, char *argv[])
     }
     else if (!strcmp(argv[argp], "-d") || !strcmp(argv[argp], "--debug"))
       debug = 1;
+    else if (!strcmp(argv[argp], "-f") || !strcmp(argv[argp], "--fg"))
+      fg = 1;
     else if ((!strcmp(argv[argp], "-c") || !strcmp(argv[argp], "--cmdfile"))
 	     && (argp + 1 < argc))
       cmdpath = argv[++argp];
@@ -484,7 +488,7 @@ int main(int argc, char *argv[])
    */
   if (!debug)
   {
-    ret = daemon(0, 0);
+    ret = fg ? fg : daemon(0, 0);
     if (ret < 0)
     {
       error_fatal("Could not daemonize", errno);
